@@ -1,23 +1,35 @@
 from __future__ import annotations
 
-import os
 import re
 import sys
-from typing import Any
+from typing import TYPE_CHECKING, TypedDict
 
 from commitizen import factory, git, out
-from commitizen.config import BaseConfig
 from commitizen.exceptions import (
     InvalidCommandArgumentError,
     InvalidCommitMessageError,
     NoCommitsFoundError,
 )
 
+if TYPE_CHECKING:
+    from commitizen.config import BaseConfig
+
+
+class CheckArgs(TypedDict, total=False):
+    commit_msg_file: str
+    commit_msg: str
+    rev_range: str
+    allow_abort: bool
+    message_length_limit: int
+    allowed_prefixes: list[str]
+    message: str
+    use_default_range: bool
+
 
 class Check:
     """Check if the current commit msg matches the commitizen format."""
 
-    def __init__(self, config: BaseConfig, arguments: dict[str, Any], cwd=os.getcwd()):
+    def __init__(self, config: BaseConfig, arguments: CheckArgs, *args: object) -> None:
         """Initial check command.
 
         Args:
@@ -25,16 +37,19 @@ class Check:
             arguments: All the flags provided by the user
             cwd: Current work directory
         """
-        self.commit_msg_file: str | None = arguments.get("commit_msg_file")
-        self.commit_msg: str | None = arguments.get("message")
-        self.rev_range: str | None = arguments.get("rev_range")
-        self.allow_abort: bool = bool(
+        self.commit_msg_file = arguments.get("commit_msg_file")
+        self.commit_msg = arguments.get("message")
+        self.rev_range = arguments.get("rev_range")
+        self.allow_abort = bool(
             arguments.get("allow_abort", config.settings["allow_abort"])
         )
-        self.max_msg_length: int = arguments.get("message_length_limit", 0)
+
+        self.use_default_range = bool(arguments.get("use_default_range"))
+        self.max_msg_length = arguments.get(
+            "message_length_limit", config.settings.get("message_length_limit", 0)
+        )
 
         # we need to distinguish between None and [], which is a valid value
-
         allowed_prefixes = arguments.get("allowed_prefixes")
         self.allowed_prefixes: list[str] = (
             allowed_prefixes
@@ -42,74 +57,80 @@ class Check:
             else config.settings["allowed_prefixes"]
         )
 
-        self._valid_command_argument()
-
-        self.config: BaseConfig = config
-        self.encoding = config.settings["encoding"]
-        self.cz = factory.committer_factory(self.config)
-
-    def _valid_command_argument(self):
         num_exclusive_args_provided = sum(
             arg is not None
-            for arg in (self.commit_msg_file, self.commit_msg, self.rev_range)
+            for arg in (
+                self.commit_msg_file,
+                self.commit_msg,
+                self.rev_range,
+            )
         )
-        if num_exclusive_args_provided == 0 and not sys.stdin.isatty():
-            self.commit_msg = sys.stdin.read()
-        elif num_exclusive_args_provided != 1:
+
+        if num_exclusive_args_provided > 1:
             raise InvalidCommandArgumentError(
                 "Only one of --rev-range, --message, and --commit-msg-file is permitted by check command! "
                 "See 'cz check -h' for more information"
             )
 
-    def __call__(self):
+        if num_exclusive_args_provided == 0 and not sys.stdin.isatty():
+            self.commit_msg = sys.stdin.read()
+
+        self.config: BaseConfig = config
+        self.cz = factory.committer_factory(self.config)
+
+    def __call__(self) -> None:
         """Validate if commit messages follows the conventional pattern.
 
         Raises:
-            InvalidCommitMessageError: if the commit provided not follows the conventional pattern
+            InvalidCommitMessageError: if the commit provided does not follow the conventional pattern
+            NoCommitsFoundError: if no commit is found with the given range
         """
         commits = self._get_commits()
         if not commits:
             raise NoCommitsFoundError(f"No commit found with range: '{self.rev_range}'")
 
-        pattern = self.cz.schema_pattern()
-        ill_formatted_commits = [
-            commit
+        pattern = re.compile(self.cz.schema_pattern())
+        invalid_commits = [
+            (commit, check.errors)
             for commit in commits
-            if not self.validate_commit_message(commit.message, pattern)
+            if not (
+                check := self.cz.validate_commit_message(
+                    commit_msg=commit.message,
+                    pattern=pattern,
+                    allow_abort=self.allow_abort,
+                    allowed_prefixes=self.allowed_prefixes,
+                    max_msg_length=self.max_msg_length,
+                    commit_hash=commit.rev,
+                )
+            ).is_valid
         ]
-        displayed_msgs_content = "\n".join(
-            [
-                f'commit "{commit.rev}": "{commit.message}"'
-                for commit in ill_formatted_commits
-            ]
-        )
-        if displayed_msgs_content:
+
+        if invalid_commits:
             raise InvalidCommitMessageError(
-                "commit validation: failed!\n"
-                "please enter a commit message in the commitizen format.\n"
-                f"{displayed_msgs_content}\n"
-                f"pattern: {pattern}"
+                self.cz.format_exception_message(invalid_commits)
             )
         out.success("Commit validation: successful!")
 
-    def _get_commits(self):
-        msg = None
-        # Get commit message from file (--commit-msg-file)
-        if self.commit_msg_file is not None:
-            # Enter this branch if commit_msg_file is "".
-            with open(self.commit_msg_file, encoding=self.encoding) as commit_file:
-                msg = commit_file.read()
-        # Get commit message from command line (--message)
-        elif self.commit_msg is not None:
-            msg = self.commit_msg
-        if msg is not None:
-            msg = self._filter_comments(msg)
-            return [git.GitCommit(rev="", title="", body=msg)]
+    def _get_commit_message(self) -> str | None:
+        if self.commit_msg_file is None:
+            # Get commit message from command line (--message)
+            return self.commit_msg
+
+        with open(
+            self.commit_msg_file, encoding=self.config.settings["encoding"]
+        ) as commit_file:
+            # Get commit message from file (--commit-msg-file)
+            return commit_file.read()
+
+    def _get_commits(self) -> list[git.GitCommit]:
+        if (msg := self._get_commit_message()) is not None:
+            return [git.GitCommit(rev="", title="", body=self._filter_comments(msg))]
 
         # Get commit messages from git log (--rev-range)
-        if self.rev_range:
-            return git.get_commits(end=self.rev_range)
-        return git.get_commits()
+        return git.get_commits(
+            git.get_default_branch() if self.use_default_range else None,
+            self.rev_range,
+        )
 
     @staticmethod
     def _filter_comments(msg: str) -> str:
@@ -134,22 +155,10 @@ class Check:
             The filtered commit message without comments.
         """
 
-        lines = []
+        lines: list[str] = []
         for line in msg.split("\n"):
             if "# ------------------------ >8 ------------------------" in line:
                 break
             if not line.startswith("#"):
                 lines.append(line)
         return "\n".join(lines)
-
-    def validate_commit_message(self, commit_msg: str, pattern: str) -> bool:
-        if not commit_msg:
-            return self.allow_abort
-
-        if any(map(commit_msg.startswith, self.allowed_prefixes)):
-            return True
-        if self.max_msg_length:
-            msg_len = len(commit_msg.partition("\n")[0].strip())
-            if msg_len > self.max_msg_length:
-                return False
-        return bool(re.match(pattern, commit_msg))
